Success Stories
===============

Want to see examples of Briefcase in use? Here's some:

* `Travel Tips <https://apps.apple.com/au/app/travel-tips/id1336372310>`_ is
  an app in the iOS App Store that was packaged for distribution using
  Briefcase.

* `Mu <https://codewith.mu>`_ is a simple code editor for beginner programmers.
  It uses Briefcase to prepare a macOS installer.

* `Napari <https://napari.org/>`_ is a multi-dimensional image viewer for python.
  It uses Briefcase to prepare bundled Windows, MacOS, and Linux installers.
